document.addEventListener('DOMContentLoaded', function () {
	const today = new Date()
	const dateFormat = /(\d{4})([\/-])(\d{1,2})\2(\d{1,2})._/ // "YYYY-MM-DD" format for event titles
	let now = dayjs()
	let modalEventChange = false
	let copyInProgress = false

	//MovieRecorder Connection Info
	address = window.location.hostname
	port = window.location.port

	//Settings - MovieRecorder Options
	let defaultDestinations = []

	if (localStorage.getItem('defaultDestinations')) {
		defaultDestinations = JSON.parse(localStorage.getItem('defaultDestinations'))
	}

	// Settings - Calendar Options
	let weekends = false
	let dayStart = '08:00'

	if (localStorage.getItem('weekends') != null) {
		weekends = localStorage.getItem('weekends') === 'true' ? true : false
	}
	if (localStorage.getItem('dayStart') != null) {
		dayStart = localStorage.getItem('dayStart')
	}

	//Check if user is on a phone or other small screen
	mobileCheck = function () {
		if (/Android|webOS|iPhone|iPad/i.test(navigator.userAgent)) {
			return true
		} else {
			return false
		}
	}

	//Create Calendar
	var calendarEl = document.getElementById('calendar')
	var calendar = new FullCalendar.Calendar(calendarEl, {
		aspectRatio: mobileCheck() ? 1 : 2,
		headerToolbar: {
			left: 'prev,next today',
			center: 'title',
			right: 'dayGridMonth,timeGridWeek,timeGridDay,listWeek',
		},
		allDaySlot: false,
		navLinks: true,
		dayMaxEvents: true,
		eventMaxStack: 3,
		weekends: weekends,
		initialView: mobileCheck() ? 'timeGridDay' : 'timeGridWeek',
		scrollTime: dayStart,
		slotMinTime: '00:00:00',
		slotMaxTime: '24:00:00',
		initialDate: today,
		nowIndicator: true,
		selectable: true,
		snapDuration: '00:05',
		editable: true,
		events: {},
		eventClick: function (info) {
			if (info.event.durationEditable) {
				newEditModal(info.event)
			}
		},
		select: function (event) {
			newRecModal(event)
		},
		eventChange: function (info) {
			if (modalEventChange == false) {
				eventMoved(info.event)
			}
		},
		eventOverlap: function (stillEvent, movingEvent) {
			return stillEvent.extendedProps.source_unique_id !== movingEvent.extendedProps.source_unique_id
		},
		eventAllow: function (dropInfo, draggedEvent) {
			//Prevent moving recurring events between days, only allow time changes
			if (draggedEvent.extendedProps.recurring === true) {
				return dayjs(dropInfo.start).format('YYYY[-]MM[-]DD') === dayjs(draggedEvent.start).format('YYYY[-]MM[-]DD')
			} else {
				return true
			}
		},
		datesSet: function (info) {
			if (!copyInProgress) {
				if (info.view.type == 'timeGridWeek' || info.view.type == 'listWeek') {
					$('.copyButton').text('Copy Week')
					$('.pasteButton').text('Paste Week')
				} else if (info.view.type == 'timeGridDay') {
					$('.copyButton').text('Copy Day')
					$('.pasteButton').text('Paste Day')
				} else if (info.view.type == 'dayGridMonth') {
					$('.copyButton').text('Copy Month')
					$('.pasteButton').text('Paste Month')
				}
			}
		},
	})

	calendar.render()

	var sources = []
	var scheduledRecordings = []
	var copyDates = []
	var colors = [
		'#5d439c',
		'#1d5799',
		'#d76700',
		'#298a71',
		'#8f466a',
		'#65758f',
		'#bc911e',
		'#277b1f',
		'#a491d9',
		'#86abe6',
		'#f4ad6c',
		'#85d1be',
	]
	var activeRecColor = '#b11d1a'
	var pastRecColor = '#4e4e4e'

	//Calculate start time in format needed for MovieRecorder API
	minutesFromMidnight = function (date) {
		let hours = date.getHours()
		let minutes = date.getMinutes()
		return 60 * hours + minutes
	}
	//Assign colors to each source
	colorPicker = function (source) {
		let color = '#b1b1b1'
		for (s in sources) {
			if (source == sources[s]?.unique_id) {
				color = colors[s]
			}
		}
		return color
	}
	//Remove dates from calendar event names to increase readability
	removeDateFromTitle = function (name) {
		return name.replace(dateFormat, '')
	}
	//Check if recording name is unique, and append an integer to the name if it is not
	checkNameAvailability = function (name, int) {
		let regex = /_\d+$/i // "_int" at the end of the name

		if (!scheduledRecordings.find((o) => o.name == name)) {
			return name
		} else {
			name = name.replace(regex, '')
			if (int) {
				int++
				name = name + '_' + int
				return checkNameAvailability(name, int)
			} else {
				let int = 1
				name = name + '_' + int
				return checkNameAvailability(name, int)
			}
		}
	}
	//Get Destinations from MovieRecorder
	fetch(`http://${address}:${port}/destinations`)
		.then((res) => {
			if (res.status == 200) {
				return res.json()
			}
			if (res.status == 401) {
				$('.newRec').hide()
				$('#noConnection').delay(250).slideDown(400)
			}
		})
		.then((json) => {
			let data = json
			let availDestinations = []
			for (let s in data) {
				let destination = data[s]

				let destinationInfo = {
					name: destination.name,
					unique_id: destination.unique_id,
				}
				availDestinations.push(destinationInfo)
			}
			availDestinations.sort((a, b) => a.name.localeCompare(b.name))
			return availDestinations
		})
		.then((availDestinations) => {
			for (let s in availDestinations) {
				let destination = availDestinations[s]

				$('#selectDestinations').append(`<option value="${destination.unique_id}">${destination.name}</option>`)
				$('#selectDestinations').selectpicker('refresh')
				$('#defaultDestinations').append(`<option value="${destination.unique_id}">${destination.name}</option>`)
				$('#defaultDestinations').selectpicker('refresh')
			}
		})
		.catch((err) => {
			$('.newRec').hide()
			$('#noConnection').delay(250).slideDown(400)
		})

	//Get Sources from MovieRecorder
	fetch(`http://${address}:${port}/sources`)
		.then((res) => {
			if (res.status == 200) {
				return res.json()
			}
		})
		.then((json) => {
			let data = json
			for (let s in data) {
				let source = data[s]

				let sourceInfo = {
					display_name: source.display_name,
					unique_id: source.unique_id,
				}
				sources.push(sourceInfo)
			}
			sources.sort((a, b) => a.display_name.localeCompare(b.display_name))
			return sources
		})
		.then((sources) => {
			for (let s in sources) {
				let source = sources[s]

				$('#selectSource').append(`<option value="${source.unique_id}">${source.display_name}</option>`)
				$('#selectSource').selectpicker('refresh')
			}
		})
		.then(() => {
			//Ensures sources are known before populating recordings
			//Get Scheduled Recordings from MovieRecorder
			fetch(`http://${address}:${port}/scheduled_recordings`)
				.then((res) => {
					if (res.status == 200) {
						return res.json()
					}
				})
				.then((json) => {
					let data = json
					scheduledRecordings = data //Store scheduled recordings to reference later

					for (let s in data) {
						let scheduledRec = data[s]

						if (scheduledRec.is_enabled && scheduledRec.source_unique_id) {
							let startTime =
								dayjs(scheduledRec.date).format('YYYY[-]MM[-]DD') +
								dayjs(scheduledRec.date).startOf('day').add(scheduledRec.start_time, 'm').format('[T]HH:mm')
							let endTime = dayjs(startTime).add(scheduledRec.duration, 'm').format('YYYY[-]MM[-]DD[T]HH:mm')
							let color = colorPicker(scheduledRec.source_unique_id)

							let editable = true
							let calendarTitle = removeDateFromTitle(scheduledRec.name)

							//Stylize Past Recordings
							if (dayjs(startTime).isBefore(now)) {
								color = pastRecColor
								editable = false
							}
							//Stylize Active Recordings
							if ((dayjs(scheduledRec.date).isSame(now), 'date')) {
								if (dayjs(startTime).isBefore(now) && dayjs(endTime).isAfter(now) && !scheduledRec.stopped_by_user) {
									color = activeRecColor
									editable = false
								}
							}
							let event = {
								id: scheduledRec.unique_id,
								title: calendarTitle,
								start: startTime,
								end: endTime,
								editable: editable,
								backgroundColor: color,
								//extendedProps
								name: scheduledRec.name,
								source_name: scheduledRec.source_name,
								source_unique_id: scheduledRec.source_unique_id,
								destinations: scheduledRec.destination_unique_ids,
							}
							//Displaying recurring recordings
							if (scheduledRec.weekly_repeated) {
								delete event.start
								delete event.end
								event.editable = true
								event.startRecur = dayjs().format('YYYY[-]MM[-]DD')
								event.startTime = dayjs().startOf('day').add(scheduledRec.start_time, 'm').format('HH:mm')
								event.endTime = dayjs(startTime).add(scheduledRec.duration, 'm').format('HH:mm')
								event.backgroundColor = colorPicker(scheduledRec.source_unique_id)
								event.daysOfWeek = scheduledRec.recording_days
								event.groupId = scheduledRec.unique_id
								//extendedProps
								event.recurring = true
								event.recordingDays = scheduledRec.recording_days
							}

							calendar.addEvent(event)
						}
					}
				})
		})
	// Add recording to MovieRecorder
	addRec = function () {
		let source = $('#selectSource').val()
		let destinations = []
		let selectedDestinations = []
		$('#selectDestinations :selected').each(function () {
			selectedDestinations.push({ unique_id: $(this).val(), destination_name: $(this).text() })
		})
		for (s in selectedDestinations) {
			destinations.push(selectedDestinations[s].unique_id)
		}

		let title = $('#newTitle').val()

		if (source && destinations.length > 0) {
			let data = {
				is_enabled: true,
				source_unique_id: source,
				destination_unique_ids: destinations,
			}

			//Avoid using default destination names if other names are present
			let destinationName = 'New Recording'

			for (s in selectedDestinations) {
				if (destinationName == 'New Recording') {
					if (!defaultDestinations.includes(selectedDestinations[s].unique_id)) {
						destinationName = selectedDestinations[s].destination_name
					}
				}
			}
			if (destinationName == 'New Recording') {
				destinationName = selectedDestinations[0].destination_name
			}

			let startTime = new Date($('#startDate').val() + 'T' + $('#startTime').val() + ':00')
			data.start_time = minutesFromMidnight(startTime)
			let endTime = new Date($('#startDate').val() + 'T' + $('#endTime').val() + ':00')
			data.duration = minutesFromMidnight(endTime) - minutesFromMidnight(startTime)

			if ($('#repeatingEvent:checked').val()) {
				data.weekly_repeated = true
				let days = []
				$('input[type=checkbox]:checked').each(function () {
					days.push(parseInt(this.value))
				})
				data.recording_days = days
			} else {
				data.date = startTime
				data.weekly_repeated = false
			}

			if (title == '') {
				title = destinationName
			}
			let fileNameDate = dayjs(startTime).format('YYYY[-]MM[-]DD') + '_'
			let name = data.weekly_repeated == true ? title : fileNameDate + title
			data.name = checkNameAvailability(name)

			publishRec = function (data) {
				fetch(`http://${address}:${port}/scheduled_recordings/`, {
					method: 'POST',
					headers: {
						'Content-Type': 'application/json',
					},
					body: JSON.stringify(data),
				})
					.then((res) => {
						if (res.status == 200) {
							return res.json()
						}
					})
					.then((json) => {
						if (json.success) {
							let color = colorPicker(source)
							let calendarTitle = removeDateFromTitle(data.name)
							let event = {
								id: json.unique_id,
								title: calendarTitle,
								editable: true,
								backgroundColor: color,
								//extendedProps
								name: name,
								source_name: source,
								source_unique_id: source,
								destinations: destinations,
							}
							if (data.weekly_repeated) {
								event.startRecur = dayjs().format('YYYY[-]MM[-]DD')
								;(event.startTime = $('#startTime').val()), (event.endTime = $('#endTime').val())
								event.daysOfWeek = data.recording_days
								event.groupId = json.unique_id
								event.recurring = true
								event.recordingDays = data.recording_days
							} else {
								event.start = startTime
								event.end = endTime
							}
							$('#newRecModal').modal('hide')
							calendar.addEvent(event)
							scheduledRecordings.push(data)
							$('#addedName').text('Recording ' + event.title + ' Scheduled')
							$('#alertScheduled').delay(250).slideDown(400).delay(2000).slideUp(400)

							calendar.render()
						} else if (json.error && json.error == 'Expected an array of integers for recording days') {
							alert('Select at least one day of the week to record.')
						} else {
							alert(json.error)
						}
					})
			}
			if (data.name && data.duration >= 1) {
				publishRec(data)
			} else if (data.duration < 1) {
				alert('End time must be after start time.')
			}
		} else if (source && destinations.length == 0) {
			alert('Please select at least one destination')
		} else if (!source && destinations.length > 0) {
			alert('Please select a source')
		} else {
			alert('Please select a source & at least one destination')
		}
	}
	// Remove recording from MovieRecorder
	cancelRec = function (event) {
		fetch(`http://${address}:${port}/scheduled_recordings/${event.id}`, {
			method: 'DELETE',
			headers: {
				'Content-Type': 'application/json',
			},
		})
			.then((res) => {
				if (res.status == 200) {
					return res.json()
				}
			})
			.then((json) => {
				if (json.success) {
					$('#newRecModal').modal('hide')
					$('#canceledName').text('Recording ' + event.title + ' Canceled')
					$('#alertCanceled').delay(250).slideDown(400).delay(2000).slideUp(400)
					event.remove()
					calendar.render()
				} else {
					alert(json.error)
				}
			})
	}
	// Edit recording in MovieRecorder
	modifyRec = function (event, data) {
		fetch(`http://${address}:${port}/scheduled_recordings/${event.id}`, {
			method: 'PUT',
			headers: {
				'Content-Type': 'application/json',
			},
			body: JSON.stringify(data),
		})
			.then((res) => {
				if (res.status == 200) {
					return res.json()
				}
			})
			.then((json) => {
				if (json.success) {
					let title = removeDateFromTitle(data.name)
					modalEventChange = true //Prevents Full Calendar eventChange listener from starting an infinite loop
					event.setProp('title', title)
					event.setExtendedProp('name', data.name)
					modalEventChange = false
					$('#newRecModal').modal('hide')
					$('#updatedName').text('Recording ' + event.title + ' Updated')
					$('#alertModify').delay(250).slideDown(400).delay(2000).slideUp(400)

					calendar.render()

					scheduledRecordings.push(data)
				} else if (json.error && json.error == 'Expected a valid integer duration') {
					alert('End time must be after start time.')
				} else if (json.error && json.error == 'Expected an array of integers for recording days') {
					alert('Select at least one day of the week to record.')
				} else {
					alert(json.error)
				}
			})
	}
	// Triggered when an event is dragged on calendar
	eventMoved = function (event) {
		let data = {
			unique_id: event.id,
			weekly_repeated: event.extendedProps.recurring == true ? true : false,
		}

		let startTime = new Date(event.start)
		data.start_time = minutesFromMidnight(startTime)

		data.duration = dayjs(event.end).diff(dayjs(event.start), 'minute')
		let fileNameDate = dayjs(startTime).format('YYYY[-]MM[-]DD') + '_'

		let title = removeDateFromTitle(event.extendedProps.name)
		let name = data.weekly_repeated == true ? title : fileNameDate + title
		//Replace old event with moved event info
		scheduledRecordings.splice(scheduledRecordings.findIndex((o) => o.unique_id == event.id))
		//Keep this before name check to prevent false positive with old event info
		data.name = checkNameAvailability(name)

		if (event.extendedProps.recurring) {
			data.recording_days = event.extendedProps.recordingDays
		} else {
			data.date = startTime
		}
		modifyRec(event, data)
	}

	//Modals
	//New Recording Modal (Triggered by New Recording button, or by clicking empty cal area)
	newRecModal = function (event) {
		$('#recordingModal').text('New Recording')
		$('.cancel').hide()
		$('.edit').hide()
		$('.duplicate').hide()
		$('.create').show()

		$('#specificDateInfo').show()
		$('#repeatingEventInfo').hide()

		$('#specificDate').click(function () {
			$('#specificDateInfo').slideDown()
			$('#repeatingEventInfo').slideUp()
		})
		$('#repeatingEvent').click(function () {
			$('#specificDateInfo').slideUp()
			$('#repeatingEventInfo').slideDown()
		})
		$('label[for="specificDate"]').css('pointer-events', 'auto')
		$('label[for="repeatingEvent"]').css('pointer-events', 'auto')
		$('input:checkbox').prop('checked', false)
		$('#specificDate').prop('checked', true)
		$('#repeatingEvent').prop('checked', false)
		$('#selectSource').selectpicker('val', '')
		$('#selectDestinations').selectpicker('deselectAll')
		if (defaultDestinations.length > 0) {
			$('#selectDestinations').selectpicker('val', defaultDestinations)
		}
		$('#newTitle').val('')

		if (event) {
			$('#startDate').val(dayjs(event.start).format('YYYY[-]MM[-]DD'))
			$('#startTime').val(dayjs(event.start).format('HH[:]mm'))
			$('#endTime').val(dayjs(event.end).format('HH[:]mm'))
			$(`#${dayjs(event.start).day()}`).prop('checked', true)
		} else {
			now = dayjs()
			$('#startDate').val(now.format('YYYY[-]MM[-]DD'))
			$('#startTime').val(now.add(30, 'm').format('HH[:]mm'))
			$('#endTime').val(now.add(60, 'm').format('HH[:]mm'))
		}
		$('#newRecModal').modal('show')
		$('.create')
			.off('click')
			.on('click', function () {
				addRec()
			})
	}
	//Edit Recording Modal (Triggered by clicking an existing event)
	newEditModal = function (event) {
		$('#recordingModal').text('Edit Recording')
		$('.cancel').show()
		$('.edit').show()
		$('.duplicate').show()
		$('.create').hide()
		$('#selectSource').selectpicker('val', event.extendedProps.source_unique_id)
		$('#selectDestinations').selectpicker('val', event.extendedProps.destinations)
		$('#newTitle').val('')

		//Prevent changing type in edit modal
		$('label[for="specificDate"]').css('pointer-events', 'none')
		$('label[for="repeatingEvent"]').css('pointer-events', 'none')

		if (event.extendedProps.recurring) {
			$('#specificDate').prop('checked', false)
			$('#repeatingEvent').prop('checked', true)

			$('#specificDateInfo').hide()
			$('#repeatingEventInfo').show()

			$('input:checkbox').prop('checked', false)

			for (d in event.extendedProps.recordingDays) {
				$(`#${event.extendedProps.recordingDays[d]}`).prop('checked', true)
			}
		} else {
			$('#specificDate').prop('checked', true)
			$('#repeatingEvent').prop('checked', false)

			$('#specificDateInfo').show()
			$('#repeatingEventInfo').hide()
		}
		$('#startDate').val(dayjs(event.start).format('YYYY[-]MM[-]DD'))
		$('#startTime').val(dayjs(event.start).format('HH[:]mm'))
		$('#endTime').val(dayjs(event.end).format('HH[:]mm'))
		$('#newTitle').val(event.title)

		$('#newRecModal').modal('show')
		$('.cancel')
			.off('click')
			.on('click', function () {
				cancelRec(event)
			})
		$('.edit')
			.off('click')
			.on('click', function () {
				let destinations = []
				let title = $('#newTitle').val()
				let selectedDestinations = $('#selectDestinations').val()
				for (s in selectedDestinations) {
					destinations.push(selectedDestinations[s])
				}
				let source = $('#selectSource').val()
				if (source && destinations.length > 0) {
					let data = {
						is_enabled: true,
						source_unique_id: source,
						destination_unique_ids: destinations,
					}

					let destinationSelected = document.getElementById('selectDestinations')
					let destinationName = destinationSelected.options[destinationSelected.selectedIndex].text

					let startTime = new Date($('#startDate').val() + 'T' + $('#startTime').val() + ':00')
					data.start_time = minutesFromMidnight(startTime)
					let endTime = new Date($('#startDate').val() + 'T' + $('#endTime').val() + ':00')
					data.duration = minutesFromMidnight(endTime) - minutesFromMidnight(startTime)

					if ($('#repeatingEvent:checked').val()) {
						data.weekly_repeated = true
						let days = []
						$('input[type=checkbox]:checked').each(function () {
							days.push(parseInt(this.value))
						})
						data.recording_days = days
					} else {
						data.date = startTime
						data.weekly_repeated = false
					}

					if (title == '') {
						title = destinationName
					}
					let fileNameDate = dayjs(startTime).format('YYYY[-]MM[-]DD') + '_'
					let name = data.weekly_repeated == true ? title : fileNameDate + title
					//Replace old event with moved event info
					scheduledRecordings.splice(scheduledRecordings.findIndex((o) => o.unique_id == event.id))
					//Keep this before name check to prevent false positive with old event info
					data.name = checkNameAvailability(name)

					modalEventChange = true
					if (data.weekly_repeated) {
						event.setStart(startTime)
						event.setEnd(endTime)
					} else {
						event.setDates(startTime, endTime)
					}
					let color = colorPicker(source)
					event.setProp('color', color)
					event.setExtendedProp('source_unique_id', source)
					event.setExtendedProp('destinations', destinations)
					event.setExtendedProp('recordingDays', data.recording_days)
					modalEventChange = false
					modifyRec(event, data)
				} else if (source && destinations.length == 0) {
					alert('Please select at least one destination')
				} else if (!source && destinations.length > 0) {
					alert('Please select a source')
				} else {
					alert('Please select a source & at least one destination')
				}
			})
		$('.duplicate')
			.off('click')
			.on('click', function () {
				addRec()
			})
	}
	//Settings Modal (Triggered by clicking the Settings button)
	newSettingsModal = function () {
		if (defaultDestinations.length > 0) {
			$('#defaultDestinations').selectpicker('val', defaultDestinations)
		}
		$('#weekends').selectpicker('val', `${weekends}`)
		$('#dayStart').val(dayStart)

		$('#settingsModal').modal('show')
		$('.adjustSettings')
			.off('click')
			.on('click', function () {
				defaultDestinations = $('#defaultDestinations').val()
				localStorage.setItem('defaultDestinations', JSON.stringify(defaultDestinations))

				weekends = $('#weekends').val()
				localStorage.setItem('weekends', weekends)

				dayStart = $('#dayStart').val()
				localStorage.setItem('dayStart', dayStart)

				$('#settingsModal').modal('hide')

				location.reload()
			})
	}
	//Triggered by Copy button
	//Gathers info for all events in current calendar view
	copyRecInfo = function () {
		copyDates = []
		copyInProgress = true

		let calEnd = new Date(calendar.view.activeEnd)
		calEnd.setDate(calEnd.getDate() - 1)
		var getDaysArray = function (start, end) {
			for (var arr = [], dt = new Date(start); dt <= end; dt.setDate(dt.getDate() + 1)) {
				arr.push(dayjs(dt).format('YYYY[-]MM[-]DD'))
			}
			return arr
		}
		copyDates = getDaysArray(new Date(calendar.view.activeStart), new Date(calEnd))

		$('.copyButton').hide()
		$('.cancelPaste').show()
		$('.pasteButton').show()
	}
	//Triggered by Paste button
	//Calculates difference between current view + copied view, then creates new events for all copied events
	pasteRec = function () {
		copyInProgress = false

		let calViewDate = calendar.view.activeStart
		let allEvents = calendar.getEvents()
		let dayDiff = dayjs(calViewDate).diff(dayjs(copyDates[0]), 'day')

		for (let s in allEvents) {
			let event = allEvents[s]
			if (copyDates.includes(dayjs(event.start).format('YYYY[-]MM[-]DD'))) {
				function addDays(date, days) {
					var result = new Date(date)
					result.setDate(date.getDate() + days)
					return result
				}

				let startTime = addDays(new Date(event.start), dayDiff)
				let endTime = addDays(new Date(event.end), dayDiff)
				let duration = dayjs(event.end).diff(dayjs(event.start), 'minute')

				let fileNameDate = dayjs(startTime).format('YYYY[-]MM[-]DD')
				let name = fileNameDate + '_' + event.title
				name = checkNameAvailability(name)

				let data = {
					date: startTime,
					start_time: minutesFromMidnight(startTime),
					duration: duration,
					name: name,
					weekly_repeated: false,
					is_enabled: true,
					source_unique_id: event.extendedProps.source_unique_id,
					destination_unique_ids: event.extendedProps.destinations,
				}

				fetch(`http://${address}:${port}/scheduled_recordings/`, {
					method: 'POST',
					headers: {
						'Content-Type': 'application/json',
					},
					body: JSON.stringify(data),
				})
					.then((res) => {
						if (res.status == 200) {
							return res.json()
						}
					})
					.then((json) => {
						if (json.success) {
							let color = colorPicker(data.source_unique_id)
							let event = {
								id: json.unique_id,
								title: removeDateFromTitle(data.name),
								start: startTime,
								end: endTime,
								editable: true,
								backgroundColor: color,
								//extendedProps
								name: data.name,
								source_name: data.source_name,
								source_unique_id: data.source_unique_id,
								destinations: data.destination_unique_ids,
							}

							calendar.addEvent(event)

							calendar.render()
						} else {
							$('#canceledName').text('Unable to copy ' + data.name)
							$('#alertCanceled').delay(250).slideDown(400).delay(2000).slideUp(400)
						}
					})
			}
		}
		$('.copyButton').show()
		$('.pasteButton').hide()
		$('.cancelPaste').hide()
	}
	//Triggered by Cancel Paste button
	//Clears copied events and resets paste-related buttons
	cancelPaste = function () {
		copyDates = []
		copyInProgress = false
		if (calendar.view.type == 'timeGridWeek' || calendar.view.type == 'listWeek') {
			$('.copyButton').text('Copy Week')
			$('.pasteButton').text('Paste Week')
		} else if (calendar.view.type == 'timeGridDay') {
			$('.copyButton').text('Copy Day')
			$('.pasteButton').text('Paste Day')
		} else if (calendar.view.type == 'dayGridMonth') {
			$('.copyButton').text('Copy Month')
			$('.pasteButton').text('Paste Month')
		}
		$('.copyButton').show()
		$('.pasteButton').hide()
		$('.cancelPaste').hide()
	}
})
